@@ -254,8 +254,9 @@ class MyApp(wx.App):
                     DTCCodes=self.port.get_dtc()
 
                     print DTCCodes
-                    print DTCCodes[0][0]
-                    print DTCCodes[0][1]
+                    #print DTCCodes[0][0] | bug with no DTC codes
+                    #print DTCCodes[0][1] | bug with no DTC codes
+
                     if len(DTCCodes)==0:
                       wx.PostEvent(self._notify_window, DTCEvent(["","","No DTC codes (codes cleared)"]))
                     for i in range (0,len(DTCCodes)):
@@ -560,7 +561,7 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-10beta
+        Text = """pyobd-0.9.2-11
 Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
